@@ -39,21 +39,18 @@ class Select(AbstractStatement):
     def generate_sql(self):
         table_name = self.table.get_name()
         select_sql = self._construct_select_sql()
+        distinct_on_sql = self._construct_distinct_on_sql()
         where_sql = self._construct_where_sql()
         group_sql = self._construct_group_sql()
         order_sql = self._construct_order_sql()
         limit_sql = self._construct_limit_sql()
         offset_sql =self._construct_offset_sql()
-        sql = f"{select_sql} FROM {table_name} {where_sql} {group_sql} {order_sql} {limit_sql} {offset_sql}"
+        sql = f"SELECT {distinct_on_sql} {select_sql} FROM {table_name} {where_sql} {group_sql} {order_sql} {limit_sql} {offset_sql}"
         logger.debug(f"constructed {sql=}")
         return sql
 
     def _construct_select_sql(self) -> str:
-        select_sql = ', '.join(selectable.to_selector() for selectable in self.selectables)
-        if distinct_on_sql := self._construct_distinct_on_sql():
-            select_sql = f"{distinct_on_sql} {select_sql} "
-
-        return f"SELECT {select_sql}"
+        return ', '.join(selectable.to_selector() for selectable in self.selectables)
 
     def _construct_distinct_on_sql(self) -> str:
         distinct_on_sql = ""
